import requests
import json

from .constants import BASE_URL

class Schedule:

    def today(self, id=None):
        self.id = id
        if self.id == None:
            response = requests.get('%s/schedule' % (BASE_URL))
            self.data = response.json()
            del self.data['copyright']
            return self.data
        else:
            response = requests.get('%s/schedule?teamId=%s' % (BASE_URL, str(self.id)))
            self.data = response.json()
            del self.data['copyright']
            return self.data


    def date(self, start_date=None, end_date=None):
        self.start_date = start_date
        self.end_date = end_date

        if self.start_date == None and self.end_date == None:
            return self.today()
        elif self.start_date != None and self.end_date == None:
            response = requests.get('%s/schedule%s%s' % (BASE_URL, '?date=', str(self.start_date)))
            self.data = response.json()
            del self.data['copyright']
            return self.data
        else:
            return self.today()

    """
    Returns line score for today's completed games. Can't add date parameters to this.
    """
    def linescore(self):
        response = requests.get('%s/schedule?expand=schedule.linescore' % (BASE_URL))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def tickets(self):
        response = requests.get('%s/schedule?expand=schedule.ticket' % (BASE_URL))
        self.data = response.json()
        del self.data['copyright']
        return self.data








import requests
import json

from .constants import BASE_URL

class Game:

    def __init__(self, id):
        self.id = id

    """
    Returns over 30k lines of detailed game information
    """

    def all_stats(self):
        response = requests.get('%s/game/%s/feed/live' % (BASE_URL, str(self.id)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def boxscore(self):
        response = requests.get('%s/game/%s/boxscore' % (BASE_URL, str(self.id)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def media(self):
        response = requests.get('%s/game/%s/content' % (BASE_URL, str(self.id)))
        self.data = response.json()
        del self.data['copyright']
        return self.data







import requests
import json

from .constants import BASE_URL

class Division:

    """
    Shows only active divisions
    """

    def all(self):
        response = requests.get('%s/divisions' % (BASE_URL))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    """
    Can show inactive divisions if specified
    """

    def info(self, id):
        self.id = id
        response = requests.get('%s/divisions/%s' % (BASE_URL, self.id))
        self.data = response.json()
        del self.data['copyright']
        return self.data







import requests
import json

from .constants import BASE_URL

class Team:

    def __init__(self, id):
        self.id = id

    def info(self):
        response = requests.get('%s/teams/%s' % (BASE_URL, str(self.id)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def roster(self):
        path = 'https://statsapi.web.nhl.com/api/v1/teams/{}'.format(self.id)
        path = path + '?expand=team.roster'
        response = requests.get(path)
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def name(self):
        for team in self.data['teams']:
            print(team['name'])

    def next_game(self):
        path = 'https://statsapi.web.nhl.com/api/v1/teams/{}'.format(self.id)
        path = path + '?expand=team.schedule.next'
        response = requests.get(path)
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def last_game(self):
        path = 'https://statsapi.web.nhl.com/api/v1/teams/{}'.format(self.id)
        path = path + '?expand=team.schedule.previous'
        response = requests.get(path)
        self.data = response.json()
        del self.data['copyright']
        return self.data

    """
    Returns single season stats, regular season stat rankings, and general information about team
    """
    def stats(self):
        path = 'https://statsapi.web.nhl.com/api/v1/teams/{}'.format(self.id)
        path = path + '?expand=team.stats'
        response = requests.get(path)
        self.data = response.json()
        del self.data['copyright']
        return self.data

    """
    Only returns the single season stats and regular season stat ranknings
    """
    def stats_simple(self):
        response = requests.get('%s/teams/%s/stats' % (BASE_URL, str(self.id)))
        self.data = response.json()
        del self.data['copyright']
        return self.data







import requests
import json

from .constants import BASE_URL

class Player:

    def __init__(self, id):
        self.id = id

    """
    Gets details for player, id must be specified to return data
    """

    def info(self):
        response = requests.get('%s/people/%s' % (BASE_URL, str(self.id)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    """
    Get single season stats for a player. Two valid consecutive years must
    be specified.
    """

    def season(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=statsSingleSeason&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def home_away(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=homeAndAway&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def win_loss(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=winLoss&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def split_by_month(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=byMonth&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def split_by_day(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=byDayOfWeek&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def split_by_division(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=vsDivision&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def split_by_conference(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=vsConference&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def split_by_team(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=vsTeam&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def split_by_game(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=gameLog&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def standing(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=regularSeasonStatRankings&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    def goals_by_situation(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=goalsByGameSituation&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data

    """
    This only works with the current in-progress season during the regular season
    """
    def on_pace_stats(self, year_start, year_end):
        self.year_start = year_start
        self.year_end = year_end
        response = requests.get('%s/people/%s/%s%s%s' % (BASE_URL, str(self.id),
            'stats?stats=onPaceRegularSeason&season=', str(self.year_start), str(self.year_end)))
        self.data = response.json()
        del self.data['copyright']
        return self.data
















from distutils.core import setup
setup(
        name = 'nhlpy',
        packages = ['nhlpy'],
        version = '0.2.1',
        description = 'An easy to use NHL API wrapper',
        author = 'Alexander Delgado',
        author_email = 'jobehico@gmail.com',
        url = 'https://github.com/0xalexdelgado/nhlpy',
        download_url = 'https://github.com/0xalexdelgado/nhlpy/archive/0.2.tar.gz',
        keywords = ['hockey', 'API', 'NHL', 'wrapper', 'api', 'nhlpy', 'statistics'],
        classifiers = [],
        )

